@@ -20,9 +20,17 @@ def is_executable(path: Path) -> bool:
 LN = find_executable("gln", "ln")
 
 
-HOME = Path.home()
+def home() -> Path:
+    try:
+        return Path(os.environ["MYBOX_HOME"])
+    except KeyError:
+        pass
 
-LOCAL = HOME / ".local"
+    return Path.home()
+
+
+def local() -> Path:
+    return home() / ".local"
 
 
 def transplant_path(dir_from: Path, dir_to: Path, path: Path) -> Path:
