@@ -1,6 +1,7 @@
 import argparse
 
 from .package import load_packages
+from .state.base import DB, DB_PATH
 from .utils import flatten, parallel_map_tqdm
 
 
@@ -14,10 +15,16 @@ def parser() -> argparse.ArgumentParser:
 
 
 def main():
+    db = DB(DB_PATH)
     args = parser().parse_args()
     components: frozenset[str] = frozenset(args.component) | {"base"}
-    packages = flatten(map(load_packages, components))
+    packages = flatten(load_packages(db, component) for component in components)
     map_fn = map if args.sequential else parallel_map_tqdm
-    results = map_fn(lambda p: p.ensure(), packages)
-    total_installed = sum(1 if installed else 0 for installed in results)
-    print(f"{total_installed} packages installed or updated.")
+    results = map_fn(lambda p: p.name if p.ensure() else None, packages)
+    installed = list(filter(None, results))
+    if installed:
+        print(
+            f"{len(installed)} packages installed or updated: {', '   .join(installed)}"
+        )
+    else:
+        print("Everything up to date.")
