@@ -3,6 +3,7 @@ from typing import Any, Tuple, Type
 
 import yaml
 
+from ..state.base import DB
 from .base import Package
 from .clone import Clone
 from .github import GitHubPackage
@@ -27,19 +28,19 @@ TYPES: list[Tuple[str, Type[Package]]] = [
 ]
 
 
-def parse_package(package: Any) -> Package:
+def parse_package(db: DB, package: Any) -> Package:
     if not isinstance(package, dict):
         raise ValueError(f"Dictionary expected, got: {package}.")
 
     for key, package_type in TYPES:
         if key in package:
-            return package_type(**package)
+            return package_type(**package, db=db)
 
     keys = ", ".join(f"'{key}'" for key, _ in TYPES)
     raise ValueError(f"Either of {keys} must be present, got: {package}.")
 
 
-def load_packages(component: str) -> list[Package]:
+def load_packages(db: DB, component: str) -> list[Package]:
     with open(Path("packages") / f"{component}.yaml") as f:
         packages = yaml.safe_load(f)
-        return list(map(parse_package, packages))
+        return [parse_package(db, package) for package in packages]
