@@ -2,7 +2,8 @@ from abc import ABCMeta, abstractmethod
 from functools import cached_property
 from typing import Optional
 
-from ..utils import *
+from ..state import DB, VERSIONS, Table, Version
+from ..utils import CURRENT_DISTRIBUTION, CURRENT_OS, OS, Distribution, Some, unsome_
 
 
 class Package(metaclass=ABCMeta):
@@ -11,9 +12,12 @@ class Package(metaclass=ABCMeta):
 
     def __init__(
         self,
+        *,
+        db: DB,
         os: Some[OS] = None,  # pylint:disable=redefined-outer-name
         distribution: Some[Distribution] = None,
     ) -> None:
+        self.db = db
         self.os = unsome_(os)
         self.distribution = unsome_(distribution)
 
@@ -43,7 +47,8 @@ class Package(metaclass=ABCMeta):
     def install(self) -> None:
         pass
 
-    def ensure(self) -> bool:
+    @property
+    def applicable(self) -> bool:
         if self.os is not None and CURRENT_OS not in self.os:
             return False
         if (
@@ -52,7 +57,16 @@ class Package(metaclass=ABCMeta):
             and CURRENT_DISTRIBUTION not in self.distribution
         ):
             return False
+        return True
+
+    def ensure(self) -> bool:
+        if not self.applicable:
+            return False
         if self.is_installed:
             return False
         self.install()
         return True
+
+    @cached_property
+    def versions(self) -> Table[Version]:
+        return VERSIONS(self.db)
