@@ -6,8 +6,10 @@ from functools import cache
 from threading import Lock
 from typing import Optional
 
-from ..state import VERSIONS, Version
-from ..utils import *
+import requests
+
+from ..state import Version
+from ..utils import Some, run, run_output, unsome, url_version, with_os
 from .base import Package
 
 
@@ -40,32 +42,63 @@ class Brew(Installer):
         run("brew", "upgrade", package)
 
     @cache
-    def info(self, package: str) -> tuple[str, Optional[str]]:
-        info = json.loads(run_output("brew", "info", "--json=v2", package))
+    def brew_info(self, package: str) -> dict:
+        return json.loads(run_output("brew", "info", "--json=v2", package))
+
+    def installed_version(self, package: str) -> Optional[str]:
+        info = self.brew_info(package)
         if info["casks"]:
             cask = info["casks"][0]
-            return cask["version"], cask["installed"]
+            return cask["installed"]
         if info["formulae"]:
             formula = info["formulae"][0]
             try:
                 installed = formula["installed"][0]["version"]
             except IndexError:
                 installed = None
-            version = formula["versions"]["stable"]
-            revision = formula.get("revision")
-            if revision:
-                version += f"_{revision}"
-            return version, installed
+            return installed
         raise ValueError(f"Unexpected output from brew: {info}")
 
-    def installed_version(self, package: str) -> Optional[str]:
-        try:
-            return self.info(package)[1]
-        except IndexError:
-            return None
+    def api(self, path: str) -> dict:
+        result = requests.get(f"https://formulae.brew.sh/api/{path}")
+        result.raise_for_status()
+        return result.json()
 
+    CASK_PREFIX = "homebrew/cask/"
+
+    @cache
     def latest_version(self, package: str) -> str:
-        return self.info(package)[0]
+        if package.startswith(self.CASK_PREFIX):
+            # Cask
+            # https://formulae.brew.sh/docs/api/#get-formula-metadata-for-a-cask-formula
+            cask_package = package[len(self.CASK_PREFIX) :]
+            cask = self.api(f"cask/{cask_package}.json")
+            return cask["version"]
+        elif "/" not in package:
+            # Normal formula
+            # https://formulae.brew.sh/docs/api/#get-formula-metadata-for-a-core-formula
+            formula = self.api(f"formula/{package}.json")
+            return self.formula_version(formula)
+        else:
+            # Non-core cask or formula?
+            # https://github.com/Homebrew/discussions/discussions/3618
+            info = self.brew_info(package)
+            if info.get("formulae"):
+                formula = info["formulae"][0]
+                return self.formula_version(formula)
+            elif info.get("casks"):
+                cask = info["casks"][0]
+                return cask["version"]
+            else:
+                raise ValueError(f"Unknown package: {package}")
+
+    @staticmethod
+    def formula_version(info: dict) -> str:
+        version = info["versions"]["stable"]
+        revision = info.get("revision")
+        if revision:
+            version += f"_{revision}"
+        return version
 
 
 class DNF(Installer):
@@ -189,7 +222,7 @@ class SystemPackage(Package):
     def local_version(self) -> Optional[str]:
         if self.url:
             try:
-                return VERSIONS[self.name].version
+                return self.versions[self.name].version
             except KeyError:
                 return None
         if self.auto_updates:
@@ -209,7 +242,7 @@ class SystemPackage(Package):
         with INSTALLER_LOCK:
             if self.url:
                 INSTALLER.install(self.url)
-                VERSIONS[self.name] = Version(version=self.get_remote_version())
+                self.versions[self.name] = Version(version=self.get_remote_version())
             elif self.local_version:
                 INSTALLER.upgrade(self.name)
             else:
