@@ -1,8 +1,9 @@
 import concurrent.futures
+import re
 import subprocess
 import sys
 from threading import Lock
-from typing import Callable, Iterable, Literal, Optional, TypeVar, Union, cast
+from typing import Callable, Iterable, Iterator, Literal, Optional, TypeVar, Union, cast
 
 import requests
 import tqdm  # type: ignore
@@ -126,6 +127,31 @@ class Filters:
     def endswith(suffix: str) -> Callable[[str], bool]:
         return lambda x: x.endswith(suffix)
 
+    @staticmethod
+    def regex(regex: str) -> Callable[[str], bool]:
+        regex_compiled = re.compile(regex)
+
+        return lambda x: regex_compiled.match(x) is not None
+
+
+def choose(candidates: list[T], filters: Iterator[Callable[[T], bool]]) -> T:
+    if len(candidates) == 0:
+        raise ValueError("No candidates to choose from.")
+    while len(candidates) > 1:
+        try:
+            filter_fn = next(filters)
+        except StopIteration:
+            break
+
+        new_candidates = list(filter(filter_fn, candidates))
+        if new_candidates:
+            candidates = new_candidates
+
+    if len(candidates) == 1:
+        return candidates[0]
+
+    raise ValueError(f"Cannot choose between: {candidates}.")
+
 
 def url_version(url: str) -> str:
     head_response = requests.head(url, allow_redirects=True)
